import org.serviio.library.metadata.*
import org.serviio.library.online.*

/**
 * Generic LiveFeeds URL extractor plugin. 
 * Invoked by anyurl/LiveFeeds*
 *    
 * @author JHB50
 *
 */
class LiveFeeds extends FeedItemUrlExtractor {

	final VALID_FEED_URL = '^http(s)*://.*?LiveFeeds.*?'
	List itemNode
	
	String getExtractorName() {
		return 'LiveFeeds'
	}
    
	boolean extractorMatches(URL feedUrl) {
		//println "feedUrl = " + feedUrl
		
		//get the rss contents if feed matches this groovy
		if (feedUrl ==~ VALID_FEED_URL)	{
			def rssPage = new URL(feedUrl.toString()).getText()
			def rssPagetmp = rssPage.replaceAll('&amp;','&')
			def rssPagenew = rssPagetmp.replaceAll('&','&amp;')
			//println "rssPagenew = " + rssPagenew
			//now parse the rss contents into items
			def rssNodes = new XmlParser().parseText(rssPagenew)
			//println "rssNodes = " + rssNodes
			// and create a list of items
			itemNode = rssNodes.channel.item
			//println "itemNode = " + itemNode
			//println " "
		}
 		return feedUrl ==~ VALID_FEED_URL
	}

	ContentURLContainer extractUrl(Map links, PreferredQuality requestedQuality) {
		def linkUrl = links.default  /* The <link> tag */
		def contentUrl    /* The video to be played to be returned */
		def thumbnailUrl  /* The thumbnail to be displayed in DLNA menu - to be returned */
		//println "links = " + links
		// display the <link> tag
		//println "linkUrl = " + linkUrl

		// look at each item to find the link url and keep the match
		def matchedItem
		// set matchedItem with contents of Item with matching link
		itemNode.each { it -> if(it.link.text() == linkUrl.toString()) matchedItem = it }  

		//println " "
		println "matchedItem = " + matchedItem
		//println " "
		
		
		//now extract the stream url ... detect all characters that can be in livestream urls (? _=@&.-)
		def mediaLink = matchedItem =~ '(?s)stream\\[attributes=\\{.*?url=([\\w:/\\?\\ \\_\\=\\@\\&\\.\\-]+)[,}]'
		
		//println "mediaLink = " + mediaLink[0][1]
		//println " "
                
		contentUrl = mediaLink[0][1]

		//now check the stream type for audio 
		def mediaTypeAudio = matchedItem ==~ '.*?stream\\[attributes=\\{.*?type=audio.*?'
		//println "mediaTypeAudio = " + mediaTypeAudio
		MediaFileType fileType = MediaFileType.VIDEO;
		if( mediaTypeAudio == true ) fileType = MediaFileType.AUDIO
				
		//now extract the thumbnail url <<< not required ..Serviio will find it in the selected item.
		//def thumbLink = matchedItem =~ '(?s)thumbnail\\[attributes=\\{url=([\\w:/\\?\\=\\.\\-]+)};'
		
		//println "thumbLink = " + thumbLink[0][1]
		//println " "
                
		//thumbnailUrl = thumbLink[0][1]

		def live = true
		
		return new ContentURLContainer(fileType: fileType, contentUrl: contentUrl, thumbnailUrl: thumbnailUrl, live: live)
	}

	static void main(args) {
		// this is just to test
		LiveFeeds extractor = new LiveFeeds()
		
		assert extractor.extractorMatches( new URL("https://sites.google.com/site/jhbrsstest/LiveFeeds_TVStationsTest.rss"))

		Map videoLinks = ['default': new URL('http://link2')]
		ContentURLContainer result = extractor.extractUrl(videoLinks,PreferredQuality.HIGH)
		println "Result: $result"		 
	}
}